--------------------------------------------------------------------------------------------
-- server.lua - Demonstrates a very simple server
--------------------------------------------------------------------------------------------
require ("configure_me");  --Include the file 'configure_me.lua'
require ("ticket");        --Include the file 'ticket.lua'
require ("library");       --Include the file 'library.lua'

--Check the input file:
if (not DoesFileExist(input_path..inputfile)) then
   ErrorMail("Input file '"..input_path..inputfile.."' doesn't exist (Customer "..customername..")");
end

--Create a new project and import the imput file:
NewProject();
projectImport(input_path..inputfile);

--The import should automatically find the software version. Let's check:
if (string.len(projectGetProperty(ePrjPropEcuSoftwareversion))==0) then
   ErrorMail("Can't detect software version for input file '"..input_path..inputfile.."' (Customer "..customername..")");
end

--We should have a file for that software version. Let's check:
local tuningfilename = tuningtemplate_path.."sw"..projectGetProperty(ePrjPropEcuSoftwareversion)..".dat";
if (not DoesFileExist(tuningfilename)) then
   ErrorMail("Can't find tuning file "..tuningfilename.." for input file '"..input_path..inputfile.."' (Customer "..customername..")");
end

--We want to import it over the eprom:
projectSetElement(eElementEprom);
projectImport(tuningfilename);

--Let's apply the checksum:
projectApplyChecksums();

--Let's make sure that all checksums are okay:
if (projectStatChecksums()~=0) then
   ErrorMail("Can't calculate checksum for input file '"..input_path..inputfile.."' (Customer "..customername..")");
end

--Export the file:
projectExport(input_path.."tuned.BdmToGo", eFiletypeBdmToGo, "", binaryor(eBdmToGoProgramEprom, eBdmToGoProgramEprom2, eBdmToGoProgramEEprom, eBdmToGoProgramProcessor, eBdmToGoNoReimport));

--Send the file to the customer:
projectMail (customermail, "Tuned version", "Dear customer, please find the tuned version attached", input_path.."tuned.BdmToGo");

--Remove the file after sending it:
os.remove (input_path.."tuned.BdmToGo");

projectClose();  --Close the version that created when saving, when exporting
projectClose();  --Close the original
Quit();